@@ -2,28 +2,14 @@
     kmime_parsers.cpp
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001 the KMime authors.
+    SPDX-FileCopyrightText: 2001 the KMime authors.
     See file AUTHORS for details
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "kmime_parsers.h"
 
 #include <QRegularExpression>
-#include <QByteArray>
 
 using namespace KMime::Parser;
 
@@ -33,9 +19,9 @@ namespace Parser
 {
 
 MultiPart::MultiPart(const QByteArray &src, const QByteArray &boundary)
+    : m_src(src)
+    , m_boundary(boundary)
 {
-    m_src = src;
-    m_boundary = boundary;
 }
 
 bool MultiPart::parse()
@@ -47,7 +33,7 @@ bool MultiPart::parse()
     m_parts.clear();
 
     //find the first valid boundary
-    while (1) {
+    while (true) {
         if ((pos1 = m_src.indexOf(b, pos1)) == -1 || pos1 == 0 ||
                 m_src[pos1 - 1] == '\n') { //valid boundary found or no boundary at all
             break;
@@ -73,7 +59,7 @@ bool MultiPart::parse()
             //now search the next linebreak
             //now find the next valid boundary
             pos2 = ++pos1; //pos1 and pos2 point now to the beginning of the next line after the boundary
-            while (1) {
+            while (true) {
                 if ((pos2 = m_src.indexOf(b, pos2)) == -1 ||
                         m_src[pos2 - 1] == '\n') { //valid boundary or no more boundaries found
                     break;
